import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import { areaRecord } from '@/api/demo/cascader';
import { treeDataList } from '@/views/dataStandards/referenceDocument/mock';
// 引入开关组件
type CheckedType = boolean | string | number;

export const columnsTwo: BasicColumn[] = [
  {
    title: '名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 120,
  },
];
export const batchColumns: BasicColumn[] = [
  {
    title: '日期类',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '共享工作区/日期类',
    dataIndex: 'type',
    width: 120,
  },
];
export const columns: BasicColumn[] = [
  {
    title: '文档名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '文档编号',
    dataIndex: 'num',
    width: 120,
  },
  {
    title: '发布状态',
    dataIndex: 'flag',
    width: 120,
  },
  {
    title: '权属工作组',
    dataIndex: 'group',
    width: 120,
  },
];

export const applySchemas1: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '搜索资源名称',
    },
  },
];

export const applySchemas3: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    defaultValue: '短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    defaultValue: '共享工作区/短编号',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue: '域',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
];
export const applySchemas2: FormSchema[] = [
  {
    field: '',
    label: '数据标准详情',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    slots: 'path',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'path',
    label: '标准路径',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
];
export const applySchemas: FormSchema[] = [
  {
    field: '',
    label: '申请信息',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '申请标题',
    component: 'Input',
    defaultValue: '申请发布<日期类>等2个域',
    componentProps: {},
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
    defaultValue: '',
    componentProps: {},
  },
  {
    field: 'user',
    label: '申请人',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'org',
    label: '所属机构',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'time',
    label: '申请时间',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '文档名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文档名称',
    },
  },
  {
    field: 'num',
    label: '文档编号',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文档编号',
    },
  },
];

export const formSchema: FormSchema[] = [
  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '文档分类名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文档分类名称',
      },
    ],
  },
  {
    field: 'describe',
    component: 'InputTextArea',
    label: '标准分类描述',
    required: true,
    componentProps: {
      placeholder: '请输入标准分类描述',
      rows: 4,
    },
  },
  {
    field: 'modal',
    component: 'Cascader',
    label: '关联元模型',
    required: true,
    componentProps: {
      // dataField: 'data',
      labelField: 'value',
      valueField: 'label',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'flag',
    label: '权限模式',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '本级定义', value: '1' },
        { label: '资源自定义', value: '0' },
      ],
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Select',
    componentProps: {
      options: [
        { label: '默认工作组', value: '1' },
        { label: '默认工作组2', value: '0' },
      ],
    },
  },
];
export const formSchemaManage: FormSchema[] = [
  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
  {
    field: 'name',
    label: '文档名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文档分类名称',
      },
    ],
  },
  {
    field: 'type',
    label: '标准类型',
    component: 'Input',
    defaultValue: '引用文档管理',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'modal',
    label: '目录权属模式',
    component: 'Input',
    defaultValue: '本级定义',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
  {
    field: 'group',
    label: '权属工作组',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      readonly: true,
      disabled: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
  },
];

/**详情表单1*/
export const detailSchema1: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '标准文件管理',
    rules: [
      {
        required: true,
        message: '请输入所属主题',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue: '标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    rules: [
      {
        required: true,
        message: '请输入来源定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文机构',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发文日期',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入发布文号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入重点摘录',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入重点摘录',
    },
  },
];

export const detailSchema2: FormSchema[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '标准文件管理',
    componentProps: {
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue: '标准文件A',
    colProps: { lg: 12, md: 8 },
    rules: [
      {
        required: true,
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    colProps: { lg: 12, md: 8 },
    defaultValue: '-',
    componentProps: {
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    colProps: { lg: 12, md: 8 },
    componentProps: {
      placeholder: '请输入重点摘录',
    },
  },
];
export const formSchemaImport: any = [
  {
    label: '选择本地文件',
    field: 'file',
    slot: 'file',
  },
  {
    field: 'name',
    label: '文件名',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件名',
    },
  },
];

export const importSchema: any[] = [
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];

export const moveFormSchema: any[] = [
  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
];

export const copyFormSchema: any[] = [
  {
    field: 'path',
    component: 'Cascader',
    label: '路径',
    componentProps: {
      // dataField: 'data',
      labelField: 'label',
      valueField: 'value',
      initFetchParams: {
        parentCode: '',
      },
      isLeaf: (record) => {
        return !(record.levelType < 3);
      },
      onChange: (e, ...v) => {
        console.log('ApiCascader====>:', e, v);
      },
    },
  },
];

export const contrastSchema3: any[] = [
  {
    field: 'valueOne',
    label: '所属主题',
    component: 'Input',
    defaultValue: '标准文件管理',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入所属主题',
    },
  },
  {
    field: 'valueTwo',
    label: '标准编号',
    component: 'Input',
    defaultValue: 'REF000023',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'valueThree',
    label: '标准中文名称',
    component: 'Input',
    defaultValue: '标准文件A',
    rules: [
      {
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'valueFour',
    label: '来源定义',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入来源定义',
    },
  },
  {
    field: 'valueFive',
    label: '发文机构',
    component: 'Input',
    defaultValue: '某部队',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSix',
    label: '发文日期',
    component: 'Input',
    defaultValue: '202304',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      slot: 'valueSix',
      readonly: true,
      placeholder: '请输入发文机构',
    },
  },
  {
    field: 'valueSeven',
    label: '发布文号',
    component: 'Input',
    defaultValue: '2023001',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入发布文号',
    },
  },
  {
    field: 'valueEight',
    label: '重点摘录',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入重点摘录',
    },
  },
]


/** src/views/dataStandards/namingDictionary/referenceDocument.data.ts/*/
export const contrastSchema4: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'valueOne',
    label: '名词中文名称',
    component: 'Input',
    defaultValue: '企业号',
    rules: [
      {
        message: '请输入名词中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '名词英文全称',
    component: 'Input',
    defaultValue: 'REF000023',
    rules: [
      {
        message: '请输入名词英文全称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文全称',
    },
  },
  {
    field: 'valueThree',
    label: '名词英文简称',
    component: 'Input',
    defaultValue: '标准文件A',
    rules: [
      {
        message: '请输入名词英文简称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文简称',
    },
  },
];



/** src/views/dataStandards/namingDictionary/domain/referenceDocument.data.ts*/
export const contrastSchema6: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'valueOne',
    label: '域名称',
    component: 'Input',
    defaultValue: '短编号',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词中文名称',
    },
  },
  {
    field: 'valueTwo',
    label: '父域',
    component: 'Input',
    defaultValue: '字符型',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文全称',
    },
  },
  {
    field: 'valueThree',
    label: '字段示例',
    component: 'Input',
    defaultValue: '会员号/品种代码',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入名词英文简称',
    },
  },
  {
    field: 'valueFour',
    label: '数据类型',
    component: 'Input',
    defaultValue: 'varchar',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueFive',
    label: '传统数据库数据类型',
    component: 'Input',
    defaultValue: 'varchar',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueSix',
    label: '长度',
    component: 'Input',
    defaultValue: '10',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'valueSeven',
    label: '精度',
    component: 'Input',
    defaultValue: '-',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
];

/** src/views/dataStandards/publicCode/publicCode.data.ts*/
export const contrastSchema5: FormSchema[] = [
  {
    field: '',
    label: '属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'belongingTheme',
    label: '所属主题',
    defaultValue: '投资',
    component: 'Input',
    rules: [
      {
        message: '请输入所属主题',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  // {
  //   field: 'standardPath',
  //   label: '标准路径',
  //   component: 'Input',
  //   colProps: { lg: 8, md: 8 },
  //   rules: [
  //     {
  //       required: true,
  //       message: '请输入标准路径',
  //     },
  //   ],
  //   componentProps: {
  //     style: {
  //       border: 'none',
  //       backgroundColor: 'transparent',
  //     },
  //     readonly: true,
  //     placeholder: '-',
  //   },
  // },
  {
    field: 'standardNumber',
    label: '标准编号',
    defaultValue: 'AS-004',
    component: 'Input',
    rules: [
      {
        message: '请输入标准编号',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    defaultValue: '对外投资出资方式',
    component: 'Input',
    rules: [
      {
        message: '请输入标准中文名称',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    defaultValue: '国家标准化管理委员会',
    component: 'Select',
    rules: [
      {
        message: '请选择标准来源',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    defaultValue: '对外投资出资方式',
    component: 'Input',
    rules: [
      {
        message: '请输入业务定义',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    defaultValue: '相关法律法规',
    component: 'Input',
    rules: [
      {
        message: '请输入定义依据',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'referenceDocument',
    label: '引用文档',
    defaultValue: '/引用文档',
    component: 'Input',
    rules: [
      {
        message: '请选择引用文档',
      },
    ],
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];


export const relatedBasicStandardsSchema: any[] = [
  {
    field: 'basicStandardsTree',
    label: '关联基础标准',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'standardChineseName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
  {
    field: 'relatedRelationship',
    label: '关联关系',
    component: 'Select',
    rules: [
      {
        required: true,
        message: '请选择关联关系',
      },
    ],
    componentProps: {
      options:[
        {
          label: '引用',
          value: '引用'
        },
        {
          label: '同义词',
          value: '同义词'
        },
        {
          label: '依赖',
          value: '依赖'
        },
        {
          label: '从属',
          value: '从属'
        }
      ],
      placeholder: '请选择关联关系',
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'relatedDescription',
    label: '关联描述',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入关联描述',
      },
    ],
    componentProps: {
      placeholder: '请输入关联描述',
    },
    colProps: { lg: 24, md: 24 },
  },
]
export const relatedRelationshipColumns2: BasicColumn[] = [
  {
    title: '标准名称',
    dataIndex: 'standardName',
    width: 150,
    slots: { customRender: 'standardName' },
  },
  {
    title: '标准编号',
    dataIndex: 'standardNumber',
    width: 150,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 150,
  },
  {
    title: '关联描述',
    dataIndex: 'associationDescription',
    width: 150,
  },
  {
    title: '关联关系',
    dataIndex: 'associationRelation',
    width: 150,
  },
  {
    title: '关联时间',
    dataIndex: 'associationTime',
    width: 150,
  },
  {
    title: '操作用户',
    dataIndex: 'operatorUser',
    width: 150,
  },
];

export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: '文档名称',
    component: 'Input',
    rules: [
      {
        required: true,
        message: '请输入文档名称',
      },
    ],
    componentProps: {
      placeholder: '请输入文档名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];

/**基础标准详情 表单1*/
export const contrastSchema1: FormSchema[] = [
  {
    field: '',
    label: '业务属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准编号',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准中文名称',
    },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准英文名称',
    },
  },
  {
    field: 'standardAlias',
    label: '标准别名',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入标准别名',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务定义',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options: [
        {
          label: '国际标准',
          value: '1',
        },
        {
          label: '国家标准',
          value: '2',
        },
        {
          label: '行业标准',
          value: '3',
        },
        {
          label: '行业实践',
          value: '4',
        },
        {
          label: '监管规定(人行)',
          value: '5',
        },
        {
          label: '监管规定(银监)',
          value: '6',
        },
        {
          label: '行内发文',
          value: '7',
        },
        {
          label: '行内协商一致',
          value: '8',
        },
      ],
      placeholder: '请选择标准来源',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入定义依据',
    },
  },
  {
    field: 'businessRule',
    label: '业务规则',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入业务规则',
    },
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options: [
        {
          label: '文本类',
          value: '1',
        },
        {
          label: '数值类',
          value: '2',
        },
        {
          label: '代码类',
          value: '3',
        },
        {
          label: '标志类',
          value: '4',
        },
        {
          label: '日期时间类',
          value: '5',
        },
        {
          label: '编号类',
          value: '6',
        },
      ],
      placeholder: '请选择数据类型',
    },
  },
  {
    field: 'valueRange',
    label: '取值范围',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入取值范围',
    },
  },
  {
    field: 'codeNumber',
    label: '代码编号',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入代码编号',
    },
  },
  {
    field: 'adaptability',
    label: '适应性',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options: [
        {
          label: '当前适用',
          value: '1',
        },
        {
          label: '未来适用',
          value: '2',
        },
      ],
      placeholder: '请输入适应性',
    },
  },
];
/**基础标准详情 表单2*/
export const contrastSchema11: FormSchema[] = [
  {
    field: '',
    label: '技术属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'dataDisplay',
    label: '数据显示',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据显示',
    },
  },
  {
    field: 'tecDataType',
    label: '数据类型',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据类型',
    },
  },
  {
    field: 'dataPrecision',
    label: '数据精度',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据精度',
    },
  },
  {
    field: 'dataLength',
    label: '数据长度',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入数据长度',
    },
  },
  {
    field: 'measurementUnit',
    label: '计量单位',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入计量单位',
    },
  },
];
/**基础标准详情 表单3*/
export const contrastSchema12: FormSchema[] = [
  {
    field: '',
    label: '管理属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'creator',
    label: '创建人员',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建人员',
    },
  },
  {
    field: 'updater',
    label: '更新人员',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新人员',
    },
  },
  {
    field: 'createDate',
    label: '创建日期',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入创建日期',
    },
  },
  {
    field: 'updateDate',
    label: '更新日期',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入更新日期',
    },
  },
  {
    field: 'secondaryAuthorityDepartment',
    label: '权威二级部门',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威二级部门',
    },
  },
  {
    field: 'tertiaryAuthorityDepartment',
    label: '权威三级部门',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入权威三级部门',
    },
  },
  {
    field: 'coreSystem',
    label: '核心系统',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入核心系统',
    },
  },
  {
    field: 'dataStandardStatus',
    label: '数据标准状态',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options: [
        {
          label: '有效',
          value: '1',
        },
        {
          label: '失效',
          value: '2',
        },
        {
          label: '未生效',
          value: '3',
        },
      ],
      placeholder: '请输入数据标准状态',
    },
  },
  {
    field: 'expirationDate',
    label: '失效时间',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
    },
  },
  {
    field: 'expirationReason',
    label: '失效原因',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入失效原因',
    },
  },
  {
    field: 'collaborativeDepartment',
    label: '协作部门',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '请输入协作部门',
    },
  },
];

/**基础标准详情 表单1*/
export const contrastSchema2: FormSchema[] = [
  {
    field: '',
    label: '业务属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'standardPath',
    label: '标准路径',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardNumber',
    label: '标准编号',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardChineseName',
    label: '标准中文名称',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardEnglishName',
    label: '标准英文名称',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardAlias',
    label: '标准别名',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'indicatorCaliber',
    label: '指标口径',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'referenceDocument',
    label: '引用文档',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'businessDefinition',
    label: '业务定义',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'standardSource',
    label: '标准来源',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'国际标准',
          value:'1'
        },
        {
          label:'国家标准',
          value:'2'
        },
        {
          label:'行业标准',
          value:'3'
        },
        {
          label:'行业实践',
          value:'4'
        },
        {
          label:'监管规定(人行)',
          value:'5'
        },
        {
          label:'监管规定(银监)',
          value:'6'
        },
        {
          label:'行内发文',
          value:'7'
        },
        {
          label:'行内协商一致',
          value:'8'
        },
      ],
      placeholder: '-',
    },
  },
  {
    field: 'definitionBasis',
    label: '定义依据',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'businessRule',
    label: '业务规则',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'dataType',
    label: '数据类型',
    component: 'Select',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      disabled: true,
      options:[
        {
          label:'文本类',
          value:'1'
        },
        {
          label:'数值类',
          value:'2'
        },
        {
          label:'代码类',
          value:'3'
        },
        {
          label:'标志类',
          value:'4'
        },
        {
          label:'日期时间类',
          value:'5'
        },
        {
          label:'编号类',
          value:'6'
        },
      ],
      placeholder: '-',
    },
  },
  {
    field: 'valueRange',
    label: '取值范围',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'codeNumber',
    label: '代码编号',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];
/**基础标准详情 表单2*/
export const contrastSchema21: FormSchema[] = [
  {
    field: '',
    label: '技术属性',
    component: 'BasicTitle',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'dataDisplay',
    label: '数据表示',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'dataLength',
    label: '数据长度',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'dataPrecision',
    label: '数据精度',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'measurementUnit',
    label: '计量单位',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'calculationFormula',
    label: '计算公式',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  }
];
/**基础标准详情 表单3*/
export const contrastSchema22: FormSchema[] = [
  {
    field: '',
    label: '管理属性',
    component: 'BasicTitle',
    componentProps: {
      style: {
        marginLeft: '15px',
        fontWeight: 'bold',
      },
    },
  },
  {
    field: 'creator',
    label: '创建人员',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'updater',
    label: '更新人员',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'createDate',
    label: '创建日期',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
  {
    field: 'updateDate',
    label: '更新日期',
    component: 'Input',
    componentProps: {
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readonly: true,
      placeholder: '-',
    },
  },
];
